# Buildings
This is a list of every company building in the database where you can modify, delete and add new buildings. Typing in the search field filters the buildings by name.

## Columns:
Each column has a triangle on the right. Click on the triangle to show filter options for that column. Click on the arrows next to the column name to order by that column in ascending or descending order. Hold shift while clicking to order multiple columns with individual weight.

### Name:
The name of the building.

### Address:
The building's location. You can add new addresses for use when pressing the "New Address" button at the top of the list.
